package Alien::Hunspell;

use strict;
use warnings;
use parent 'Alien::Base';

# ABSTRACT: Install hunspell
our $VERSION = '0.09_01'; # TRIAL VERSION




1;

__END__

=pod

=encoding UTF-8

=head1 NAME

Alien::Hunspell - Install hunspell

=head1 VERSION

version 0.09_01

=head1 SYNOPSIS

In your Build.PL:

 use Module::Build;
 use Alien::Hunspell;
 my $builder = Module::Build->new(
   ...
   configure_requires => {
     'Alien::Hunspell' => '0',
     ...
   },
   extra_compiler_flags => Alien::Hunspell->cflags,
   extra_linker_flags   => Alien::Hunspell->libs,
   ...
 );
 
 $build->create_build_script;

In your Makefile.PL:

 use ExtUtils::MakeMaker;
 use Config;
 use Alien::Hunspell;
 
 WriteMakefile(
   ...
   CONFIGURE_REQUIRES => {
     'Alien::Hunspell' => '0',
   },
   CCFLAGS => Alien::Hunspell->cflags . " $Config{ccflags}",
   LIBS    => [ Alien::Hunspell->libs ],
   ...
 );

In your L<FFI::Platypus> script or module:

 use FFI::Platypus;
 use Alien::Hunspell;
 
 my $ffi = FFI::Platypus->new(
   lib => [ Alien::Hunspell->dynamic_libs ],
 );

=head1 DESCRIPTION

This module provides the spelling library Hunspell.  It will either 
detect it as provided by the operating system, or download the source 
from the Internet and install it for you.  It uses L<Alien::Base>.

=head1 AUTHOR

Graham Ollis <plicease@cpan.org>

=head1 COPYRIGHT AND LICENSE

This software is copyright (c) 2015 by Graham Ollis.

This is free software; you can redistribute it and/or modify it under
the same terms as the Perl 5 programming language system itself.

=cut
